==> ovirt-engine-sdk-java-4.1.2.tar.gz: org/ovirt/engine/sdk4/internal/containers/FilterContainer.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.internal.containers;

import java.math.BigInteger;
import org.ovirt.engine.sdk4.types.Filter;
import org.ovirt.engine.sdk4.types.SchedulingPolicyUnit;

public class FilterContainer extends IdentifiedContainer implements Filter {
    private BigInteger position;
    private SchedulingPolicyUnit schedulingPolicyUnit;
    
    public BigInteger position() {
        return position;
    }
    
    public void position(BigInteger newPosition) {
        position = newPosition;
    }
    
    public boolean positionPresent() {
        return position != null;
    }
    
    public SchedulingPolicyUnit schedulingPolicyUnit() {
        return schedulingPolicyUnit;
    }
    
    public void schedulingPolicyUnit(SchedulingPolicyUnit newSchedulingPolicyUnit) {
        schedulingPolicyUnit = newSchedulingPolicyUnit;
    }
    
    public boolean schedulingPolicyUnitPresent() {
        return schedulingPolicyUnit != null;
    }
    
}

==> ovirt-engine-sdk-java-4.2.2.tar.gz: org/ovirt/engine/sdk4/internal/containers/FilterContainer.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.internal.containers;

import java.math.BigInteger;
import org.ovirt.engine.sdk4.types.Filter;
import org.ovirt.engine.sdk4.types.SchedulingPolicyUnit;

public class FilterContainer extends IdentifiedContainer implements Filter {
    private BigInteger position;
    private SchedulingPolicyUnit schedulingPolicyUnit;
    
    public BigInteger position() {
        return position;
    }
    
    public Byte positionAsByte() {
        return asByte("Filter", "position", position);
    }
    
    public Short positionAsShort() {
        return asShort("Filter", "position", position);
    }
    
    public Integer positionAsInteger() {
        return asInteger("Filter", "position", position);
    }
    
    public Long positionAsLong() {
        return asLong("Filter", "position", position);
    }
    
    public void position(BigInteger newPosition) {
        position = newPosition;
    }
    
    public boolean positionPresent() {
        return position != null;
    }
    
    public SchedulingPolicyUnit schedulingPolicyUnit() {
        return schedulingPolicyUnit;
    }
    
    public void schedulingPolicyUnit(SchedulingPolicyUnit newSchedulingPolicyUnit) {
        schedulingPolicyUnit = newSchedulingPolicyUnit;
    }
    
    public boolean schedulingPolicyUnitPresent() {
        return schedulingPolicyUnit != null;
    }
    
}
